===============================
Contributing to Neo development
===============================

.. link to bug_reports


Discussing with other Neo developers
====================================

.. goodforbeginners label

Setting up a development environment
====================================

.. instructions for beginning developers, starting with forking on Github

.. Mention that many Neo contributors are PhD students or postdocs, often with little or no previous experience


Running the test suite
======================



Writing tests
=============



Coding standards and style
==========================


Working on the documentation
============================


Writing an IO module
====================


Making a pull request
=====================


Reviewing pull requests
=======================


Making a release
================
